import { B64 } from '../utils';
export function urlLineToClashSsrServer(str) {
    // e.g hinet1.puffvip.com:1063:auth_aes128_sha1:chacha20:plain:UGFvZnU/?obfsparam=ZmE3Nzc4NzYzMS5taWNyb3NvZnQuY29t&protoparam=ODc2MzE6eHlqdHlza2Z5ZGhxc3M&remarks=W1YxXSDlj7Dmub4x&group=5rOh6IqZ5LqR
    const [prev, rest] = str.split('/?');
    // eslint-disable-next-line prefer-const
    let [server, port, protocol, cipher, obfs, password] = prev.split(':');
    const params = new URLSearchParams(rest);
    // @ts-ignore
    let { obfsparam, protoparam, remarks, group } = Array.from(params).reduce((result, [key, value]) => {
        result[key] = value;
        return result;
    }, {});
    if (remarks)
        remarks = B64.decode(remarks);
    if (group)
        group = B64.decode(group);
    if (password)
        password = B64.decode(password);
    if (obfsparam)
        obfsparam = B64.decode(obfsparam);
    if (protoparam)
        protoparam = B64.decode(protoparam);
    const ret = {
        'name': `${group || ''} - ${remarks}` || '',
        'type': 'ssr',
        server,
        'port': Number(port),
        'cipher': cipher,
        password,
        'obfs': obfs,
        'protocol': protocol,
        'obfs-param': obfsparam || '',
        'protocol-param': protoparam || '',
    };
    return ret;
}
