/**
 * 参考链接
 * - clash 文档 https://github.com/Dreamacro/clash/wiki/configuration#proxy-providers
 * - v2ray utils https://github.com/kltk/v2ray-tools/blob/master/src/vmess2config.js
 * - https://blog.kingrong.kr/js-decode-for-clash/#yi-yi-dui-ying
 *
 */
function normalize(name) {
    return name.replace(/（/g, '(').replace(/）/g, ')');
}
export function urlLineToClashVmessServer(line) {
    const server = {
        'type': 'vmess',
        'name': normalize(line.ps || ''),
        'server': line.add,
        'port': Number(line.port),
        'uuid': line.id,
        'alterId': Number(line.aid),
        'cipher': line.scy || 'auto',
        'network': line.net,
        'tls': Boolean(line.tls),
        'skip-cert-verify': true,
    };
    if (line.sni) {
        server.servername = line.sni;
    }
    // clash 不认识 tcp
    // 当 type=http 时, 转换成 clash 支持的 http
    // 其他情况先返回 null, 过滤掉
    if (server.network === 'tcp') {
        if (line.type === 'http') {
            server.network = 'http';
        }
        else {
            delete server.network;
        }
    }
    // udp
    // 不知道为什么这么写, line 里面没有表示, 机场返回的 config.yaml 里就是
    if (server.network === 'ws') {
        server.udp = true;
    }
    // network opts
    // yaml 不支持 undefined, 写成 null or ''
    if (line.host || line.path) {
        if (server.network === 'ws') {
            server['ws-opts'] = {
                path: line.path || '',
                headers: {
                    Host: line.host || '',
                },
            };
        }
        if (server.network === 'h2') {
            server['h2-opts'] = {
                host: line.host || '',
                path: line.path || '',
            };
        }
        if (server.network === 'http') {
            server['http-opts'] = {
                path: line.path || '',
                headers: {
                    Host: line.host || '',
                },
            };
        }
        if (server.network === 'grpc') {
            server['grpc-opts'] = {
                'grpc-service-name': line.path || '',
            };
        }
    }
    return server;
}
